import 'package:flutter/material.dart';
import 'eric_color.dart';
import 'eric_theme_data.dart';

const buttonPadding = EdgeInsets.fromLTRB(15.0, 7.5, 15.0, 7.5);

class PrimaryEricssonButton extends StatelessWidget {
  const PrimaryEricssonButton(
      {Key? key,
      required this.onPressed,
      required this.child,
      this.color = EricssonColors.blue,
      this.width = double.infinity})
      : super(key: key);

  final Function onPressed;
  final Widget child;
  final Color color;
  final double width;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () => onPressed,
      child: Container(
          width: double.infinity,
          padding: buttonPadding,
          decoration: BoxDecoration(
              color: color,
              borderRadius: const BorderRadius.all(Radius.circular(3.0))),
          child: Center(
            child: DefaultTextStyle(
                style: contraryTextStyle.copyWith(fontFamily: 'EricssonHilda'),
                child: child),
          )),
    );
  }
}

class SecondaryEricssonButton extends StatelessWidget {
  const SecondaryEricssonButton(
      {Key? key, required this.onPressed, required this.child, this.width = double.infinity})
      : super(key: key);

  final Function onPressed;
  final Widget child;
  final double width;

  @override
  Widget build(BuildContext context) {
    bool isDark = Theme.of(context).brightness == Brightness.dark;
    Color color = isDark ? EricssonColors.white : EricssonColors.gray05;
    return InkWell(
      onTap: () => onPressed,
      child: Container(
          padding: buttonPadding,
          width: width,
          decoration: BoxDecoration(
              border: Border.all(color: color),
              borderRadius: const BorderRadius.all(Radius.circular(3.0))),
          child: Center(
            child: DefaultTextStyle(
                style: TextStyle(fontFamily: 'EricssonHilda', color: color),
                child: child),
          )),
    );
  }
}

class WarningEricssonButton extends StatelessWidget {
  const WarningEricssonButton(
      {Key? key,
      required this.onPressed,
      required this.child,
      this.color = EricssonColors.red,
      this.width = double.infinity})
      : super(key: key);

  final Function onPressed;
  final Widget child;
  final Color color;
  final double width;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () => onPressed,
      child: Container(
          padding: buttonPadding,
          width: width,
          decoration: BoxDecoration(
              color: color,
              borderRadius: const BorderRadius.all(Radius.circular(3.0))),
          child: Center(
            child: DefaultTextStyle(
                style: contraryTextStyle.copyWith(fontFamily: 'EricssonHilda'),
                child: child),
          )),
    );
  }
}
