import 'eric_color.dart';
import 'package:flutter/material.dart';

const double baseTextSize = 14.0;
const double headline1TextSize = 84.0;
const double headline2TextSize = 56.0;
const double headline3TextSize = 28.0;
const double headline4TextSize = 14.0;

const TextStyle baseTextStyle = TextStyle(
  color: Colors.black,
  fontFamily: 'EricssonHilda',
  package: 'eric_design_language',
);

const TextStyle contraryTextStyle = TextStyle(
  color: Colors.white,
  fontFamily: 'EricssonHilda',
  package: 'eric_design_language',
);

final ThemeData ericssonThemeData = ThemeData(
    fontFamily: 'EricssonHilda',
    textTheme: TextTheme(
        bodyText1: baseTextStyle.copyWith(
          fontSize: baseTextSize,
        ),
        bodyText2: baseTextStyle.copyWith(
          fontSize: baseTextSize,
        ),
        headline1: baseTextStyle.copyWith(
          fontSize: headline1TextSize,
          fontWeight: FontWeight.w100,
        ),
        headline2: baseTextStyle.copyWith(
          fontSize: headline2TextSize,
          fontWeight: FontWeight.w200,
        ),
        headline3: baseTextStyle.copyWith(
          fontSize: headline3TextSize,
        ),
        headline4: baseTextStyle.copyWith(
          fontSize: headline4TextSize,
          fontWeight: FontWeight.w900,
        ),
        button: contraryTextStyle),
    colorScheme: const ColorScheme(
        brightness: Brightness.light,
        primary: EricssonColors.blue,
        onPrimary: Colors.white,
        secondary: EricssonColors.green,
        onSecondary: Colors.white,
        error: EricssonColors.red,
        onError: Colors.white,
        background: EricssonColors.white,
        onBackground: Colors.black,
        surface: EricssonColors.white,
        onSurface: Colors.black),
    inputDecorationTheme: const InputDecorationTheme(
        focusColor: EricssonColors.blue,
        focusedBorder: OutlineInputBorder(
            borderRadius: BorderRadius.zero,
            borderSide: BorderSide(color: EricssonColors.blue)),
        border: OutlineInputBorder(borderRadius: BorderRadius.zero)),
    buttonTheme: const ButtonThemeData(
      buttonColor: EricssonColors.blue,
      textTheme: ButtonTextTheme.normal,
    ),
    appBarTheme: const AppBarTheme(color: EricssonColors.gray05));

final ThemeData ericssonDarkThemeData = ThemeData(
    fontFamily: 'EricssonHilda',
    textTheme: TextTheme(
        bodyText1: contraryTextStyle.copyWith(
          fontSize: baseTextSize,
        ),
        bodyText2: contraryTextStyle.copyWith(
          fontSize: baseTextSize,
        ),
        headline1: contraryTextStyle.copyWith(
          fontSize: headline1TextSize,
          fontWeight: FontWeight.w100,
        ),
        headline2: contraryTextStyle.copyWith(
          fontSize: headline2TextSize,
          fontWeight: FontWeight.w200,
        ),
        headline3: contraryTextStyle.copyWith(
          fontSize: headline3TextSize,
        ),
        headline4: contraryTextStyle.copyWith(
          fontSize: headline4TextSize,
          fontWeight: FontWeight.w900,
        ),
        button: baseTextStyle),
    colorScheme: const ColorScheme(
        brightness: Brightness.dark,
        primary: EricssonColors.blue,
        onPrimary: Colors.white,
        secondary: EricssonColors.green,
        onSecondary: Colors.white,
        error: EricssonColors.red,
        onError: Colors.white,
        background: EricssonColors.gray14,
        onBackground: EricssonColors.gray95,
        surface: EricssonColors.gray09,
        onSurface: EricssonColors.white),
    inputDecorationTheme: const InputDecorationTheme(
        focusColor: EricssonColors.blue,
        focusedBorder: OutlineInputBorder(
            borderRadius: BorderRadius.zero,
            borderSide: BorderSide(color: EricssonColors.blue)),
        border: OutlineInputBorder(borderRadius: BorderRadius.zero)),
    buttonTheme: const ButtonThemeData(
      buttonColor: EricssonColors.blue,
      textTheme: ButtonTextTheme.normal,
    ));
